@@ -807,8 +807,12 @@ hidpp10_get_current_profile(struct hidpp10_device *dev, uint8_t *current_profile
 		      __CMD_PROFILE);
 
 	res = hidpp10_request_command(dev, &profile);
-	if (res)
-		return res;
+	if (res) {
+		/* Profiles not supported */
+		hidpp_log_debug(&dev->base, "Profiles not supported\n");
+		*current_profile = 0;
+		return 0;
+	}
 
 	type = profile.msg.parameters[0];
 	page = profile.msg.parameters[1];
